@@ -58,13 +58,12 @@ weird = [
 
 soothing = [
 	SoloInstrument({'channel': 3, 'midi_instr': 25, 'start': 4, 'end': 8, 'step': 4}),
-	WalkingBass({'channel':4, 'midi_instr':35, 'let_ring': True, 'start': 0}),
+	WalkingBass({'channel':4, 'start': 0}),
 	ChordInstrument({'channel':5, 'chance': 0.25, 'max_velocity': 70, 'midi_instr': 6, 'start': 0, 'step': 4}), 
 	ChromaticSoloist({'channel': 6, 'midi_instr': 21, 'start': 8, 'end': 12, 'step': 4}),
 	PowerChords({'channel': 7, 'midi_instr': 30, 'start': 8, 'end': 12, 'step': 4}),
 	FastStridePianist({'channel': 8, 'midi_instr': 1, 'max_velocity': 80, 'start': 20, 'step': 4}),
 	RockDrum({'start': 4}),
-	
 	]
 
 none = []
@@ -109,8 +108,11 @@ jazz = [
 	]
 
 jazz2 = [
-	ChromaticSoloist({'channel': 0, 'midi_instr': randrange(20,100)}),
+	SoloInstrument({'channel': 0, 'midi_instr': randrange(20,100), 'step': 6}),
+	SoloInstrument({'channel': 1, 'midi_instr': randrange(80,100), 'start': 4, 'step': 4}),
 	FastStridePianist({'channel': 5, 'start':0}),
+	JazzDrum({'start': 2}),
+	WalkingBass({'start': 4, 'channel': 4}),
 	]
 
 jazz_quartet = [
