@@ -1,6 +1,9 @@
-from mingus.extra import fluidsynth
+from mingus.midi import fluidsynth
 from mingus.containers.Note import Note
 from random import randrange
+from mingus.containers.Track import Track
+from mingus.containers.Bar import Bar
+from mingus.containers.Instrument import MidiInstrument
 
 class Instrument:
 
@@ -16,8 +19,10 @@ class Instrument:
 	end = -1
 	step = 0
 	midi_set = False
+	last_tick = (-1, -1) # iteration, tick
 	
 	def __init__(self, parameters):
+		self.track = Track()
 		self.params = parameters
 		if 'start' in parameters:
 			self.start = self.params["start"]
@@ -31,11 +36,22 @@ class Instrument:
 			self.step = parameters["step"]
 
 	def play(self, state):
-		
-		if not(self.midi_set) and 'midi_instr' in self.params:
-			fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi_instr"])
-			self.midi_set = True
 
+		if not(self.midi_set) and 'midi_instr' in self.params:
+			if not self.no_fluidsynth:
+				fluidsynth.midi.set_instrument(self.params["channel"], self.params["midi_instr"])
+			self.midi_set = True
+			i = MidiInstrument()
+			i.instrument_nr = self.params["midi_instr"]
+			self.track.instrument = i
+
+		if state["tick"] == 0:
+			if hasattr(self, "bar"):
+				self.track + self.bar
+			b = Bar()
+			b.set_meter(state["meter"])
+			b.key = state["key"]
+			self.bar = b
 			
 		if 'let_ring' not in self.params:
 			self.stop_playing_notes()
@@ -48,13 +64,25 @@ class Instrument:
 			n = self.generate_note(state)
 			v = self.generate_velocity(state)
 			if n != None:
-				fluidsynth.play_NoteContainer(n, v, \
-					self.params["channel"])
+				# Record played notes in a Track
+				if self.last_tick:
+					self.bar.place_notes(n, state["resolution"])
+				else:
+					self.bar.bar[-1][2].add_notes(n)
+
+				if not self.no_fluidsynth:
+					fluidsynth.play_NoteContainer(n,
+						v,self.params["channel"])
 				self.last_chan = self.params["channel"]
 				self.playing += n
 				self.last_played = n
 				if state["paint_function"] != None:
 					state["paint_function"](n, self.params["channel"])
+			else:
+				self.bar.place_notes([], state["resolution"])
+
+		self.last_tick = (state["iterations"], state["tick"])
+
 
 
 	def generate_note(self, state):
@@ -79,6 +107,7 @@ class Instrument:
 
 
 	def stop_playing_notes(self):
-		fluidsynth.stop_NoteContainer(self.playing,
+		if not self.no_fluidsynth:
+			fluidsynth.stop_NoteContainer(self.playing,
 				self.last_chan)
 		self.playing = []
