@@ -1,8 +1,10 @@
 from mingus.core import progressions, diatonic
 from mingus.containers.NoteContainer import NoteContainer
+from mingus.containers.Composition import Composition
 from time import sleep, time
 from random import random
 from mingus.core import chords
+from mingus.midi import MidiFileOut
 
 class Sequencer:
 
@@ -62,6 +64,7 @@ class Sequencer:
 		self.state["tick"] = self.tick
 		self.state["ticks"] = self.ticks
 		self.state["iteration_tick"] = tick
+		self.state["iterations"] = self.iterations
 		self.state["wild"] = self.wild
 		self.state["paint_function"] = self.paint_function
 
@@ -121,17 +124,20 @@ class Sequencer:
 
 				self.block_tick()
 				i += 1
+		self.output_midi()
+
+	def output_midi(self):
+		c = Composition()
+		chan = []
+		for s in self.instruments:
+			if hasattr(s, 'bar'):
+				s.track + s.bar
+			c.add_track(s.track)
+			chan.append(s.last_chan)
 		
-		self.simple_ending()
+		MidiFileOut.write_Composition(self.output_file, chan, 
+				c, self.bpm , 0)
 
-	def simple_ending(self):
-		chord = self.chords[0]
-		self.reset_state()
-		self.state["chord"] = chord
-		self.state["ticks"] = self.ticks
-		self.play_instruments()
-		sleep(self.tick_length * 10)
-		self.stop()
 
 	def replace_scale_note(self, note):
 		s = self.state["scale"]
@@ -173,6 +179,8 @@ class Sequencer:
 
 	def sync(self):
 		# Execution time of current tick
+		if self.no_fluidsynth:
+			return
 		exec_time = time() - self.tick_start
 
 		tick_length = self.block.get_tick_length(self.tick, \
